@@ -26,7 +26,8 @@ typedef enum {
 	SOUP_TLD_ERROR_INVALID_HOSTNAME,
 	SOUP_TLD_ERROR_IS_IP_ADDRESS,
 	SOUP_TLD_ERROR_NOT_ENOUGH_DOMAINS,
-	SOUP_TLD_ERROR_NO_BASE_DOMAIN
+	SOUP_TLD_ERROR_NO_BASE_DOMAIN,
+	SOUP_TLD_ERROR_NO_PSL_DATA,
 } SoupTLDError;
 
 G_END_DECLS
